## Pull Request Reminders

- [ ] Any tests that connect to model servers are marked with the `--runslow` decorator and won't be run by GitHub Actions. You should run these locally with `pytest --runslow`.
- [ ] Make sure the notebooks in the `docs` directory all run.
- [ ] Add tests for the new functionality.
